# eric7.Preferences.ConfigurationPages.TrayStarterPage

Module implementing the tray starter configuration page.

### Global Attributes

None

### Classes

TrayStarterPage | Class implementing the tray starter configuration page.

### Functions

create | Module function to create the configuration page.

## TrayStarterPage

Class implementing the tray starter configuration page.

### Derived from

ConfigurationPageBase, Ui_TrayStarterPage

### Class Attributes

None

### Class Methods

None

### Methods

TrayStarterPage | Constructor
save | Public slot to save the Python configuration.

### Static Methods

None

#### TrayStarterPage (Constructor)

TrayStarterPage()

Constructor

#### TrayStarterPage.save

save()

Public slot to save the Python configuration.

Up

## create

create(dlg)

Module function to create the configuration page.

dlg
  reference to the configuration dialog

Return:
  reference to the instantiated page (ConfigurationPageBase)

Up